==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/elements.cpp <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "elements.h"

void doElements()
{
	for (Entity *entity = (Entity*)entityManager->elementList.getFirstElement() ; entity != NULL ; entity = (Entity*)entity->next)
	{
		self = entity;
		
		bbManager->removeBox(self);
		
		if (self->flags & EF_DEAD)
		{
			entity = (Entity*)entity->previous;
			entityManager->elementList.remove(entity->next);
			continue;
		}
		
		self->thinkTime -= engine->getTimeDifference(TD_LOGIC);
		Math::limit(&self->thinkTime, 0, RAND_MAX);
		
		self->oldPosition = self->position;
		
		switch (entity->entityType)
		{
			case ET_DOOR:
				doDoor();
				break;
				
			case ET_LIFT:
			case ET_AUTOLIFT:
				doStructure();
				break;
				
			case ET_SWITCH:
				doSwitch();
				break;
			
			case ET_WINDOW:
				if (entity->health <= 0)
				{
					audio->playSound(Math::rrand(SND_GLASS_SHATTER_1, SND_GLASS_SHATTER_3), CH_ANY);
					windowShatter();
				}
				doStructure();
				break;
				
			case ET_BARRIER:
				if (entity->custom)
				{
					entity->health += (2 * engine->getTimeDifference(TD_LOGIC));
				}
				else
				{
					entity->health -= (2 * engine->getTimeDifference(TD_LOGIC));
				}
				
				Math::limit(&entity->health, 0, 250);
				
				if (entity->health > 0)
				{
					doStructure();
				}
				else
				{
					continue;
				}
				break;
				
			case ET_STRUCTURE:
			case ET_WEAK_WALL:
				if ((self->health <= 0) && (!(self->flags & EF_DYING)))
				{
					self->action = self->die;
				}
				doStructure();
				break;
				
				
			case ET_PUSHBLOCK:
				doStructure();
				break;
				
			default:
				printf("ERROR - Unknown entity (%d) in element list!\n", entity->entityType);
				exit(1);
				break;
		}
		
		bbManager->addBox(self);
	}
}

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/elements.cpp <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "elements.h"

void doElements()
{
	for (Entity *entity = (Entity*)entityManager->elementList.getFirstElement() ; entity != NULL ; entity = (Entity*)entity->next)
	{
		self = entity;
		
		bbManager->removeBox(self);
		
		if (self->flags & EF_DEAD)
		{
			//entity = (Entity*)entity->previous;
			//entityManager->elementList.remove(entity->next);
			continue;
		}
		
		self->thinkTime -= engine->getTimeDifference(TD_LOGIC);
		Math::limit(&self->thinkTime, 0, RAND_MAX);
		
		switch (entity->entityType)
		{
			case ET_DOOR:
				doDoor();
				break;
				
			case ET_LIFT:
				doStructure();
				break;
				
			case ET_SWITCH:
				doSwitch();
				break;
			
			case ET_WINDOW:
				if (entity->health <= 0)
				{
					audio->playSound(Math::rrand(SND_GLASS_SHATTER_1, SND_GLASS_SHATTER_3), CH_ANY);
					windowShatter();
				}
				doStructure();
				break;
				
			case ET_BARRIER:
				if (entity->custom)
				{
					entity->health += (2 * engine->getTimeDifference(TD_LOGIC));
				}
				else
				{
					entity->health -= (2 * engine->getTimeDifference(TD_LOGIC));
				}
				
				Math::limit(&entity->health, 0, 250);
				
				if (entity->health > 0)
				{
					doStructure();
				}
				else
				{
					continue;
				}
				break;
				
			case ET_STRUCTURE:
				if ((self->health <= 0) && (!(self->flags & EF_DYING)))
				{
					self->action = self->die;
				}
				doStructure();
				break;
				
			default:
				printf("ERROR - Unknown entity (%d) in element list!\n", entity->entityType);
				exit(1);
				break;
		}
		
		if (self->flags & EF_DEAD)
		{
			//entity = (Entity*)entity->previous;
			//entityManager->elementList.remove(entity->next);
			continue;
		}
		
		bbManager->addBox(self);
	}
}
